@@ -35,3 +35,11 @@ Mouses=   Earth.assignLifes(MouseDict, MO_SAVE)
 
 # take all form of lifes living on Earth:
 MyBox= Earth.joinLifes()
+
+# take all planets with two moons
+MyFilter= dict(num_moons=2)
+MyBox= Sun.getMultiplePlanets(jbuilder= ClsMoons, jfilter= MyFilter)
+
+# take all planets with humans
+MyFilter= dict(Humans.getField('life_id'))
+MyBox= Sun.getMultiplePlanets(jbuilder= ClsLifes, jfilter= MyFilter)
