@@ -384,15 +384,23 @@ class DbFly(Speaker):
 
     def _import_iface(self):
         iface= self._iface_instance= _DbInfo.iface_builder()
+
         for attr in self._iface_attrs:
             setattr(self, attr, getattr(iface, attr))
+
         if hasattr(self._iface_instance, '_mogrify'):
             self.mogrify= self._iface_instance._mogrify
 
     def _export_iface(self, where):
+
         for attr in self.exported_methods:
             setattr(where, attr, getattr(self, attr))
 
+        mog= getattr(self, 'mogrify', None)
+        if mog:
+            setattr(where, 'mogrify', mog)
+
+
     def lastrowid(self):
         return self._iface_instance._lastrowid()
 
@@ -468,14 +476,12 @@ class DbFly(Speaker):
             except:
                 self.log_raise('Cannot re-establish connection', BrokenConnection)
 
-            # if we are inside a trans, we have to signal 
-            # the broken transaction -> exception.
-            # otherwise, the query is tried once more
-            if self.trans_level:
-                self.log_raise('Connection re-established: transaction is lost.', 
+            # DbFly are always in transaction state, so
+            # we have to raise an exception.
+            self.log_raise('Connection re-established: transaction is lost.', 
                         ConnectionError)
         
-            return execattr(s, d)
+            #return execattr(s, d)
 
         except QueryError, e:
             self._rollback()
