@@ -290,7 +290,6 @@ class DbMother(_DbMap):
     _mo_initialized= False
     _mo_cfile= None
     _mo_false_values= [SQL_NULL, SQL_DEFAULT]
-    _mo_fuck= " MoThEr fucker!"
     _mo_session_name= "MoSession-"
     _mo_pg_oids= False
     _mo_flags= { 
@@ -1976,18 +1975,29 @@ class MotherBox(DbOne):
 
         table= self.builder.table_name
 
+        # sometime we have:
+        #   set foo= %{foo}s where foo= %{foo}s
+        # this is a problem, because %{foo}s should
+        # be traslated differently.
+        # This is a dirty hack to avoid the problem.
+        # Just change a key name:
+        #   set foo= %{up_foo}s where foo= %{foo}s
+
+        newd= {}
         res= []
         for k, v in d.iteritems():
+            newk= 'up_%s' % k
+            newd[newk] = v
             if v== SQL_DEFAULT:
                 res.append('%s= DEFAULT' % k)
             if v== SQL_DEFAULT:
                 res.append('%s= NULL' % k)
             else:
-                res.append('%s= %s' % (k, self.momma._arg_format(k)))
+                res.append('%s= %s' % (k, self.momma._arg_format(newk)))
 
         if not filter:
             filter= MoFilter()
-        filter.add_store(d)
+        filter.add_store(newd)
 
         what= _J(res)
         tbl= self.builder.table_name
